// *************************************************************************************************
//
// Horde3D Gui Extension
// --------------------------------------------------------
// 
// Author: Volker Vogelhuber
//
// *************************************************************************************************



/*	Title: Horde3D Gui Extension */

#pragma once

#include "Horde3D.h"

#ifndef DLL
#	if defined( WIN32 ) || defined( _WINDOWS )
#		define DLL extern "C" __declspec( dllimport )
#	else
#		if defined( __GNUC__ ) && __GNUC__ >= 4
#		  define DLLEXP extern "C" __attribute__ ((visibility("default")))
#   	else
#		  define DLLEXP extern "C"
#   	endif
#	endif
#endif


/*	Topic: Introduction
		Some words about the Gui Extension.
		
*/


/*
	Constants: Predefined constants
	H3DEXT_ImageSpriteNode  - Type identifier of ImageSprite scene node
*/
const int H3DEXT_ImageSpriteNode = 201;


struct H3DEXTImageSprite
{
	/*	Enum: H3DEXTImageSprite
			The available ImageSprite node parameters.

			WidthF = 20000,
			HeightF, 
			ImgScaleXF,
			ImgScaleYF
		
	*/
	enum List
	{
		WidthF = 20000,
		HeightF, 
		ImgScaleXF,
		ImgScaleYF,
		MatResI
	};
};

/*
 Function: h3dextGetGLTexID
		Retrieves the GL texture name of a texture resource 
	
	Details:
		
	
	Parameters:
		texRes        - handle to texture resource within Horde

	Returns:
		 OpenGL texture name or 0 if an error occured or the texRes is not valid
 */
DLL int h3dextGetGLTexID( H3DRes texRes );

/* Function: h3dextAddImageSpriteMaterial
		Adds an ImageSpriteNode material to the resource manager.
	
	Details:
		This function creates a new material resource for an ImageSpriteNode that references a given texture resource and
		shader to render the sprite.
	
	Parameters:		
		name          - name of the resource (must be unique)
		texRes        - texture to render by the sprite
		shaderRes     - shader used for rendering

	Returns:
		 resource handle to the material (has to be removed manually by h3dRemoveResource)
*/
DLL H3DRes h3dextAddImageSpriteMaterial(  const char* name, H3DRes texRes, H3DRes shaderRes );


/* Function: h3dextAddImageSpriteNode
		Creates an ImageSpriteNode from a specified material resource.
			
	Details:
		This function creates a new ImageSpriteNode based on the given material resource. It contains four vertices
		and scales the size based on the size of the texture referenced in the materialRes
	
	Parameters:
		parent       - handle to parent of the newly created node 
		name		 - name of the new ImageSpriteNode 
		materialRes  - material used for rendering		
		
	Returns:
		 handle to the created ImageSpriteNode or 0 in case of failure
*/
DLL H3DRes h3dextAddImageSpriteNode( H3DNode parent, const char *name, H3DRes materialRes );


