// *************************************************************************************************
//
// Horde3D Gui Extension
// --------------------------------------------------------
// 
// Author: Volker Vogelhuber
//
// *************************************************************************************************

#ifndef _Horde3DGui_ImageSpriteNode_H_
#define _Horde3DGui_ImageSpriteNode_H_

#include "egPrerequisites.h"
#include "utMath.h"
#include "egMaterial.h"
#include "egTexture.h"
#include "egScene.h"


namespace Horde3DGui
{
	using namespace Horde3D;

	
	const int SNT_ImageSpriteNode = 201;

	extern const char* vsImageSpriteDebugView;
	extern const char* fsImageSpriteDebugView;

	struct ImageSpriteNodeTpl : public SceneNodeTpl
	{		
		PMaterialResource materialRes;
		float scaleX, scaleY;
		
		ImageSpriteNodeTpl( const std::string &name, MaterialResource *matRes ) : SceneNodeTpl( SNT_ImageSpriteNode, name ), materialRes( matRes ),
			scaleX(1.0f), scaleY(1.0f)
		{
		}
	};

	
	struct ImageSpriteNodeParams
	{
		enum List
		{
			WidthF = 20000,
			HeightF, 
			ImgScaleXF,
			ImgScaleYF,
			MatResI
		};
	};
	
	class ImageSpriteNode : public SceneNode
	{
	protected:
		
		float			   _imgScaleX, _imgScaleY;
		BoundingBox        _localBBox;
		PMaterialResource  _materialRes;

		ImageSpriteNode( const ImageSpriteNodeTpl &nodeTpl );
		
		void onPostUpdate();

		void drawLayers( bool debugView );
		
	public:
		static uint32 vlImageSprite;
		static ShaderCombination debugViewShader;
		static uint32 vertexPosBuffer;
		static uint32 vertexUVBuffer;
		static uint32 indexBuffer;

		~ImageSpriteNode();
		
		static SceneNodeTpl *parsingFunc( std::map< std::string, std::string > &attribs );
		static SceneNode *factoryFunc( const SceneNodeTpl &nodeTpl );
		static void renderFunc( const std::string &shaderContext, const std::string &theClass, bool debugView,
			const Frustum *frust1, const Frustum *frust2, RenderingOrder::List order, int occSet );

		bool canAttach( SceneNode &parent );
		int getParamI( int param );
		void setParamI( int param, int value );
		float getParamF( int param, int compIdx );
		void setParamF( int param, int compIdx, float value );

		bool checkIntersection( const Vec3f &rayOrig, const Vec3f &rayDir, Vec3f &intsPos ) const;

	};
}

#endif // _Horde3DTerrain_terrain_H_
